Skip to contents

Create roxygen doc from function

Usage

droxygen(file)

Arguments

file

Path to the input code file with the function

Value

A new file is created as a roxygen doc. The file ends with "_droxygend" and is saved in the same directory as the input file.