Usage
doctor(file, level = "light")
Arguments
- file
Path to the input code file
- level
Documentation level of detail. Defaults to light. Light: Provides a description of functions and pipes. Heavy: All lines are documented (not very useful).
Value
A new R file is created adding a documentation to the code. The file ends with "_doctord" and is saved in the same directory as the input file.