R/droxygen.R
droxygen.Rd
Create roxygen doc from function
droxygen(file)
Path to the input code file with the function
A new file is created as a roxygen doc. The file ends with "_droxygend" and is saved in the same directory as the input file.